# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.6] - 2019-06-14
### Fixed
* The soneti.cron module would fail on systems with python2 as default, regardless of user preference. Now it uses `sys.executable`.
